@@ -37,7 +37,10 @@
 #include "time.h"
 #include "context.h"
 #include "layer_pastecanvas.h"
+#include "valuenode_const.h"
+#include "valuenode_scale.h"
 #include "loadcanvas.h"
+#include "filesystemnative.h"
 #include <sigc++/bind.h>
 
 #endif
@@ -46,7 +49,7 @@ using namespace synfig;
 using namespace etl;
 using namespace std;
 
-namespace synfig { extern Canvas::Handle open_canvas(const String &filename, String &errors, String &warnings); };
+namespace synfig { extern Canvas::Handle open_canvas_as(const FileSystem::Identifier &identifier, const String &as, String &errors, String &warnings); };
 
 /* === M A C R O S ========================================================= */
 
@@ -79,6 +82,7 @@ Canvas::Canvas(const String &id):
 	op_flag_	(false),
 	grow_value	(0.0)
 {
+	identifier_.file_system = FileSystemNative::instance();
 	_CanvasCounter::counter++;
 	clear();
 }
@@ -601,7 +605,7 @@ Canvas::surefind_canvas(const String &id, String &warnings)
 		else
 		{
 			String errors;
-			external_canvas=open_canvas(file_name, errors, warnings);
+			external_canvas=open_canvas_as(get_identifier().file_system->get_identifier(file_name), file_name, errors, warnings);
 			if(!external_canvas)
 				throw runtime_error(errors);
 			externals_[file_name]=external_canvas;
@@ -687,7 +691,7 @@ Canvas::find_canvas(const String &id, String &warnings)const
 		else
 		{
 			String errors, warnings;
-			external_canvas=open_canvas(file_name, errors, warnings);
+			external_canvas=open_canvas_as(get_identifier().file_system->get_identifier(file_name), file_name, errors, warnings);
 			if(!external_canvas)
 				throw runtime_error(errors);
 			externals_[file_name]=external_canvas;
@@ -860,6 +864,9 @@ Canvas::clone(const GUID& deriv_guid, bool for_export)const
 
 	canvas->set_guid(get_guid()^deriv_guid);
 
+	if (canvas->parent().empty())
+		canvas->set_file_name(get_file_name());
+
 	const_iterator iter;
 	for(iter=begin();iter!=end();++iter)
 	{
@@ -1021,8 +1028,9 @@ Canvas::remove_child_canvas(Canvas::Handle child_canvas)
 }
 
 void
-Canvas::set_file_name(const String &file_name)
+Canvas::set_file_name(const String &file_name_orig)
 {
+	String file_name = FileSystem::fix_slashes(file_name_orig);
 	if(parent())
 		parent()->set_file_name(file_name);
 	else
@@ -1073,6 +1081,19 @@ Canvas::get_file_path()const
 	return dirname(file_name_);
 }
 
+void
+Canvas::set_identifier(const FileSystem::Identifier &identifier)
+{
+	identifier_ = identifier;
+}
+
+const FileSystem::Identifier&
+Canvas::get_identifier()const
+{
+	return parent() ? parent()->get_identifier() : identifier_;
+}
+
+
 String
 Canvas::get_meta_data(const String& key)const
 {
@@ -1139,19 +1160,21 @@ synfig::optimize_layers(Time time, Context context, Canvas::Handle op_canvas, bo
 		for(iter=context,i=0;*iter;iter++,i++)
 		{
 			Layer::Handle layer=*iter;
+			
+			const float layer_visibility=context.z_depth_visibility(*layer);
 
 			// If the layer isn't active, don't worry about it
-			if(!context.active(*layer))
+			if(!context.active(*layer) || layer_visibility==0.0)
 				continue;
 
 			// Any layer with an amount of zero is implicitly disabled.
 			ValueBase value(layer->get_param("amount"));
-			if(value.get_type()==ValueBase::TYPE_REAL && value.get(Real())==0)
+			if(value.get_type()==type_real && value.get(Real())==0)
 				continue;
 
 			if(layer->get_name()=="MotionBlur" || layer->get_name()=="duplicate")
 			{
-				float z_depth(layer->get_z_depth()*1.0001+i);
+				float z_depth(layer->get_true_z_depth(time));
 
 				// If we've seen a motion blur before in this context...
 				if (seen_motion_blur_locally)
@@ -1177,23 +1200,25 @@ synfig::optimize_layers(Time time, Context context, Canvas::Handle op_canvas, bo
 	for(iter=context,i=0;*iter;iter++,i++)
 	{
 		Layer::Handle layer=*iter;
-		float z_depth(layer->get_z_depth()*1.0001+i);
+		float z_depth(layer->get_true_z_depth(time));
+		const float layer_visibility=context.z_depth_visibility(*layer);
+		//synfig::info("Visibility of %s called %s = %f", layer->get_name().c_str(), layer->get_description().c_str(), layer_visibility);
 
-		// If the layer isn't active, don't worry about it
-		if(!context.active(*layer))
+		// If the layer isn't active or isn't visible in its z depth range,
+		// don't worry about it
+		if(!context.active(*layer) || layer_visibility==0.0)
 			continue;
 
 		// Any layer with an amount of zero is implicitly disabled.
 		ValueBase value(layer->get_param("amount"));
-		if(value.get_type()==ValueBase::TYPE_REAL && value.get(Real())==0)
+		if(value.get_type()==type_real && value.get(Real())==0)
 			continue;
 
 		// note: this used to include "&& paste_canvas->get_time_offset()==0", but then
 		//		 time-shifted layers weren't being sorted by z-depth (bug #1806852)
-		if(layer->get_name()=="PasteCanvas")
+		Layer_PasteCanvas* paste_canvas(dynamic_cast<Layer_PasteCanvas*>(layer.get()));
+		if(paste_canvas!=NULL)
 		{
-			Layer_PasteCanvas* paste_canvas(static_cast<Layer_PasteCanvas*>(layer.get()));
-
 			// we need to blur the sub canvas if:
 			// our parent is blurred,
 			// or the child is lower than a local blur,
@@ -1224,7 +1249,9 @@ synfig::optimize_layers(Time time, Context context, Canvas::Handle op_canvas, bo
 					paste_sub_canvas->set_grow_value(parent_grow+paste_canvas->get_param("outline_grow").get(Real()));
 				else
 					paste_sub_canvas->set_grow_value(0.0);
-				optimize_layers(time, paste_sub_canvas->get_context(context),sub_canvas,motion_blurred);
+				ContextParams params=context.get_params();
+				paste_canvas->apply_z_range_to_params(params);
+				optimize_layers(time, paste_sub_canvas->get_context(params),sub_canvas,motion_blurred);
 			}
 
 // \todo: uncommenting the following breaks the rendering of at least examples/backdrop.sifz quite severely
@@ -1252,7 +1279,7 @@ synfig::optimize_layers(Time time, Context context, Canvas::Handle op_canvas, bo
 							throw int();
 
 						ValueBase value(layer->get_param("blend_method"));
-						if(value.get_type()!=ValueBase::TYPE_INTEGER || value.get(int())!=(int)Color::BLEND_COMPOSITE)
+						if(value.get_type()!=type_integer || value.get(int())!=(int)Color::BLEND_COMPOSITE)
 							throw int();
 					}
 
@@ -1271,8 +1298,10 @@ synfig::optimize_layers(Time time, Context context, Canvas::Handle op_canvas, bo
 				{ }
 #endif	// SYNFIG_OPTIMIZE_PASTE_CANVAS
 
-			Layer::Handle new_layer(Layer::create("PasteCanvas"));
-			dynamic_cast<Layer_PasteCanvas*>(new_layer.get())->set_muck_with_time(false);
+			etl::handle<Layer_PasteCanvas> new_layer =
+				etl::handle<Layer_PasteCanvas>::cast_dynamic( Layer::create(paste_canvas->get_name()) );
+			new_layer->set_optimized(true);
+			new_layer->set_muck_with_time(false);
 			if (motion_blurred)
 			{
 				Layer::DynamicParamList dynamic_param_list(paste_canvas->dynamic_param_list());
@@ -1282,8 +1311,8 @@ synfig::optimize_layers(Time time, Context context, Canvas::Handle op_canvas, bo
 			Layer::ParamList param_list(paste_canvas->get_param_list());
 			//param_list.erase("canvas");
 			new_layer->set_param_list(param_list);
-			dynamic_cast<Layer_PasteCanvas*>(new_layer.get())->set_sub_canvas(sub_canvas);
-			dynamic_cast<Layer_PasteCanvas*>(new_layer.get())->set_muck_with_time(true);
+			new_layer->set_sub_canvas(sub_canvas);
+			new_layer->set_muck_with_time(true);
 			layer=new_layer;
 		}
 		else					// not a PasteCanvas - does it use blend method 'Straight'?
@@ -1307,6 +1336,8 @@ synfig::optimize_layers(Time time, Context context, Canvas::Handle op_canvas, bo
 			 * returns true for layers which need to be able to see
 			 * their context.  we can't encapsulate those.
 			 */
+
+			/*
 			if (composite &&
 				Color::is_straight(composite->get_blend_method()) &&
 				!composite->reads_context())
@@ -1314,9 +1345,9 @@ synfig::optimize_layers(Time time, Context context, Canvas::Handle op_canvas, bo
 				Canvas::Handle sub_canvas(Canvas::create_inline(op_canvas));
 				// don't use clone() because it re-randomizes the seeds of any random valuenodes
 				sub_canvas->push_back(composite = composite->simple_clone());
-				layer = Layer::create("PasteCanvas");
+				layer = Layer::create("group");
 				composite->set_description(strprintf("Wrapped clone of '%s'", composite->get_non_empty_description().c_str()));
-				layer->set_description(strprintf("PasteCanvas wrapper for '%s'", composite->get_non_empty_description().c_str()));
+				layer->set_description(strprintf("Group wrapper for '%s'", composite->get_non_empty_description().c_str()));
 				Layer_PasteCanvas* paste_canvas(static_cast<Layer_PasteCanvas*>(layer.get()));
 				paste_canvas->set_blend_method(composite->get_blend_method());
 				paste_canvas->set_amount(composite->get_amount());
@@ -1325,8 +1356,38 @@ synfig::optimize_layers(Time time, Context context, Canvas::Handle op_canvas, bo
 				composite->set_amount(1.0f); // after set_time()
 				paste_canvas->set_sub_canvas(sub_canvas);
 			}
+			*/
+		}
+		// Alright, the layer is included in the sorted list
+		// let's look if it is a composite and if it is partially visible
+		etl::handle<Layer_Composite> composite = etl::handle<Layer_Composite>::cast_dynamic(layer);
+		if(composite && layer_visibility < 1.0)
+		{
+			// Let's clone the composite layer if it is not a Paste Canvas
+			// (because paste will be always new layer)
+			// Oops... not always...
+			//if(dynamic_cast<Layer_PasteCanvas*>(layer.get()) != NULL)
+				composite = composite->simple_clone();
+			// Let's scale the amount parameter by the z depth visibility
+			ValueNode::Handle amount;
+			// First look if amount is dynamic:
+			if(composite->dynamic_param_list().count("amount"))
+			{
+				amount=composite->dynamic_param_list().find("amount")->second;
+			}
+			else
+			// It is normal constant parameter
+			{
+				amount=ValueNode_Const::create(layer->get_param("amount").get(Real()));
+			}
+			// Connect a ValueNode_Scale to the amount parameter with the right sub-parameters
+			ValueNode::Handle value_node=LinkableValueNode::create("scale", ValueBase(Real()), op_canvas);
+			ValueNode_Scale::Handle scale=ValueNode_Scale::Handle::cast_dynamic(value_node);
+			scale->set_link("link", amount);
+			scale->set_link("scalar", ValueNode_Const::create(layer_visibility));
+			composite->connect_dynamic_param("amount", value_node);
+			layer=composite;
 		}
-
 		sort_list.push_back(std::pair<float,Layer::Handle>(z_depth,layer));
 		//op_canvas->push_back_simple(layer);
 	}
@@ -1504,7 +1565,7 @@ Canvas::show_structure(int i) const
 		else
 			printf(": no composite");
 		printf("\n");
-		if(layer->get_name()=="PasteCanvas")
+		if(dynamic_cast<Layer_PasteCanvas*>(layer.get()) != NULL)
 		{
 			Layer_PasteCanvas* paste_canvas(static_cast<Layer_PasteCanvas*>(layer.get()));
 			paste_canvas->get_sub_canvas()->show_structure(i+1);
@@ -1602,3 +1663,10 @@ Canvas::get_string()const
 {
 	return String("Canvas: ") + get_description();
 }
+
+void
+Canvas::fill_sound_processor(SoundProcessor &soundProcessor) const
+{
+	for(IndependentContext c = begin(); *c; ++c)
+		(*c)->fill_sound_processor(soundProcessor);
+}
