@@ -50,14 +50,6 @@
 #define gamma_in(x)				((x>=0) ? pow((float)x,1.0f/colorspace_gamma()) : -pow((float)-x,1.0f/colorspace_gamma()))
 #define gamma_out(x)			((x>=0) ? pow((float)x,     colorspace_gamma()) : -pow((float)-x,     colorspace_gamma()))
 
-#ifdef WIN32
-#include <float.h>
-#ifndef isnan
-extern "C" { int _isnan(double x); }
-#define isnan _isnan
-#endif
-#endif
-
 // For some reason isnan() isn't working on macosx any more.
 // This is a quick fix.
 #if defined(__APPLE__) && !defined(SYNFIG_ISNAN_FIX)
@@ -120,8 +112,8 @@ private:
 
 public:
 	
-	static const value_type ceil=1;	
-	static const value_type floor=0;
+	static const value_type ceil;
+	static const value_type floor;
 	
 	const String get_string(void)const;
 
@@ -589,7 +581,7 @@ private:
 public:
 	static const unsigned char ceil=255;	
 	static const unsigned char floor=0;
-	static const float range=ceil-floor;
+	static const float range;
 	static const value_type amask=0xFF<<24;
 	static const value_type rmask=0xFF<<16;
 	static const value_type gmask=0xFF<<8;
@@ -978,7 +970,7 @@ public:
 		{ return !isnan(r_) && !isnan(g_) && !isnan(b_) && !isnan(a_); }
 		
 	public:
-		CairoColorAccumulator() { }
+		CairoColorAccumulator(): a_(), r_(), g_(), b_() { }
 		
 		/*!	\param R Red
 		 **	\param G Green
@@ -1145,7 +1137,7 @@ public:
 	{ return !isnan(r_) && !isnan(g_) && !isnan(b_) && !isnan(a_); }
 
 public:
-	ColorAccumulator() { }
+	ColorAccumulator(): a_(), r_(), g_(), b_() { }
 
 	/*!	\param R Red
 	**	\param G Green
