@@ -33,10 +33,12 @@
 
 #include "context.h"
 #include "layer.h"
+#include "layer_pastecanvas.h"
 #include "string.h"
 #include "vector.h"
 #include "color.h"
 #include "valuenode.h"
+#include "transformation.h"
 
 #endif
 
@@ -94,7 +96,7 @@ IndependentContext::set_time(Time time)const
 		//        or it's a stroboscope layer,
 		//        or it's a time loop layer,
 		// then break out of the loop and set its time
-		if( /* (*context)->active() && */
+		if((*context)->active() &&
 		   (!(*context)->dirty_time_.is_equal(time) ||
 			(*context)->get_name() == "stroboscope" ||
 			(*context)->get_name() == "timeloop"))
@@ -178,7 +180,7 @@ IndependentContext::set_dirty_outlines()
 			(
 			(*context)->get_name() == "outline" ||
 			(*context)->get_name() == "advanced_outline" ||
-			(*context)->get_name() == "PasteCanvas"
+			dynamic_cast<Layer_PasteCanvas*>((*context).get()) != NULL
 			)
 		  )
 			{
@@ -199,7 +201,7 @@ Context::get_color(const Point &pos)const
 	{
 		// If this layer is active, then go
 		// ahead and break out of the loop
-		if(context.active())
+		if(context.active() && context.in_z_range())
 			break;
 
 		// Otherwise, we want to keep searching
@@ -225,7 +227,7 @@ Context::get_cairocolor(const Point &pos)const
 	{
 		// If this layer is active, then go
 		// ahead and break out of the loop
-		if(context.active())
+		if(context.active() && context.in_z_range())
 			break;
 		
 		// Otherwise, we want to keep searching
@@ -250,9 +252,9 @@ Context::get_full_bounding_rect()const
 
 	while(!context->empty())
 	{
-		// If this layer is active, then go
-		// ahead and break out of the loop
-		if(context.active())
+		// If this layer is active and visible in z_depth range,
+		// then go ahead and break out of the loop
+		if(context.active() && context.in_z_range())
 			break;
 
 		// Otherwise, we want to keep searching
@@ -311,7 +313,7 @@ Context::hit_check(const Point &pos)const
 {
 	Context context(*this);
 
-	while(!context->empty())
+	while(!context->empty() && context.in_z_range())
 	{
 		// If this layer is active, then go
 		// ahead and break out of the loop
@@ -346,6 +348,7 @@ Context::accelerated_render(Surface *surface,int quality, const RendDesc &rendde
 #endif	// SYNFIG_PROFILE_LAYERS
 	
 	const Rect bbox(renddesc.get_rect());
+	const Matrix &transfromation_matrix(renddesc.get_transformation_matrix());
 	// this is going to be set to true if this layer contributes
 	// nothing, but it's a straight blend with non-zero amount, and so
 	// it has an effect anyway
@@ -358,7 +361,7 @@ Context::accelerated_render(Surface *surface,int quality, const RendDesc &rendde
 		// If we are not active then move on to next layer
 		if(!context.active())
 			continue;
-		const Rect layer_bounds((*context)->get_bounding_rect());
+		const Rect layer_bounds(Transformation::transform_bounds(transfromation_matrix, (*context)->get_bounding_rect()));
 		// Cast current layer to composite
 		composite = etl::handle<Layer_Composite>::cast_dynamic(*context);
 		// If the box area is less than zero or the boxes do not
