@@ -24,8 +24,8 @@
 
 /* === S T A R T =========================================================== */
 
-#ifndef __SYNFIG_LAYER_PASTEIMAGE_H
-#define __SYNFIG_LAYER_PASTEIMAGE_H
+#ifndef __SYNFIG_LAYER_PASTECANVAS_H
+#define __SYNFIG_LAYER_PASTECANVAS_H
 
 /* === H E A D E R S ======================================================= */
 
@@ -37,6 +37,7 @@
 #include "canvasbase.h"
 #include "canvas.h"
 #include "rect.h"
+#include "transformation.h"
 
 /* === M A C R O S ========================================================= */
 
@@ -50,17 +51,13 @@ namespace synfig {
 */
 class Layer_PasteCanvas : public Layer_Composite, public Layer_NoDeform
 {
-	//! Layer module: defines the needed members to belong to a layer's factory.
-	SYNFIG_LAYER_MODULE_EXT
 private:
-	//! Parameter: (Vector) Origin of the paste canvas layer
+	//! Parameter: (Origin) Position offset
 	ValueBase param_origin;
-	//! Parameter: (Vector) Focus of the zoom of the paste canvas layer
-	ValueBase param_focus;
+	//! Parameter: (Transfromation) Position, rotation and scale of the paste canvas layer
+	ValueBase param_transformation;
 	//! Parameter: (etl::loose_handle<synfig::Canvas>) The canvas parameter
 	etl::loose_handle<synfig::Canvas> canvas;
-	//! Parameter: (Real) Zoom of the paste canvas layer
-	ValueBase param_zoom;
 	//! Parameter: (Time) Time offset of the paste canvas layer
 	ValueBase param_time_offset;
 	//! Parameter: (Real) The value to grow the children outline layers
@@ -76,7 +73,7 @@ private:
 	mutable int depth;
 
 	//! Boundaries of the paste canvas layer. It is the canvas's boundary
-	//! affected by the zoom, origin and focus.
+	//! affected by the origin and transformation.
 	mutable Rect bounds;
 	//! signal connection for children. Seems to be used only here
 	sigc::connection child_changed_connection;
@@ -144,14 +141,19 @@ public:
 	//! Sets the canvas parameter.
 	//! \see get_sub_canvas()
 	void set_sub_canvas(etl::handle<synfig::Canvas> x);
-	//! Gets zoom parameter
-	Real get_zoom()const { return param_zoom.get(Real()); }
 	//! Gets time offset parameter
 	Time get_time_offset()const { return param_time_offset.get(Time()); }
+
 	//! Get origin parameter
-	Point get_origin()const { return param_origin.get(Vector()); }
-	//! Get focus parameter
-	Vector get_focus()const { return param_focus.get(Vector()); }
+	Point get_origin()const { return param_origin.get(Point()); }
+	//! Get transformation parameter
+	Transformation get_transformation()const { return param_transformation.get(Transformation()); }
+	//! Get summary transformation
+	Transformation get_summary_transformation()const
+	{
+		return get_transformation().transform( Transformation(-get_origin()) );
+	}
+
 	//! Default constructor
 	Layer_PasteCanvas();
 	//! Destructor
@@ -162,6 +164,8 @@ public:
 	virtual bool set_param(const String & param, const synfig::ValueBase &value);
 	//! Get the value of the specified parameter. \see Layer::get_param
 	virtual ValueBase get_param(const String & param)const;
+	//! Sets z_range* fields of specified ContextParams \a cp
+	virtual void apply_z_range_to_params(ContextParams &cp)const;
 	//! Gets the blend color of the Layer in the context at \a pos
 	virtual Color get_color(Context context, const Point &pos)const;
 	//! Sets the time of the Paste Canvas Layer and those under it
@@ -181,6 +185,8 @@ public:
 	virtual synfig::Layer::Handle hit_check(synfig::Context context, const synfig::Point &point)const;
 	virtual void set_render_method(Context context, RenderMethod x);
 
+	virtual void fill_sound_processor(SoundProcessor &soundProcessor) const;
+
 protected:
 	//!	Function to be overloaded that fills the Time Point Set with
 	//! all the children Time Points. In this case the children Time Points
