@@ -68,13 +68,13 @@ SYNFIG_LAYER_SET_CVS_ID(Layer_Polygon,"$Id$");
 
 Layer_Polygon::Layer_Polygon():
 	Layer_Shape(1.0,Color::BLEND_COMPOSITE),
-	param_vector_list(ValueBase(std::vector<Point>()))
+	param_vector_list(ValueBase(std::vector<ValueBase>()))
 {
 	std::vector<Point> vector_list;
 	vector_list.push_back(Point(0,0.5));
 	vector_list.push_back(Point(-0.333333,0));
 	vector_list.push_back(Point(0.333333,0));
-	param_vector_list.set(vector_list);
+	param_vector_list.set_list_of(vector_list);
 	sync();
 	
 	SET_INTERPOLATION_DEFAULTS();
@@ -138,25 +138,18 @@ Layer_Polygon::add_polygon(const std::vector<Point> &point_list)
 void
 Layer_Polygon::upload_polygon(const std::vector<Point> &point_list)
 {
-	std::vector<Point> vector_list(param_vector_list.get_list().begin(), param_vector_list.get_list().end());
-	
-	vector_list.clear();
-	int i,pointcount=point_list.size();
-	for(i = 0;i < pointcount; i++)
-	{
-		vector_list.push_back(point_list[i]);
-	}
+	ValueBase::List vector_list;
+	vector_list.reserve(point_list.size());
+	for(std::vector<Point>::const_iterator i = point_list.begin(); i != point_list.end(); ++i)
+		vector_list.push_back(*i);
 	param_vector_list.set(vector_list);
 }
 
 void
 Layer_Polygon::clear()
 {
-	std::vector<Point> vector_list(param_vector_list.get_list().begin(), param_vector_list.get_list().end());
-
 	Layer_Shape::clear();
-	vector_list.clear();
-	param_vector_list.set(vector_list);
+	param_vector_list.set(ValueBase::List());
 }
 
 bool
@@ -166,7 +159,7 @@ Layer_Polygon::set_param(const String & param, const ValueBase &value)
 	{
 		param_vector_list=value;
 		Layer_Shape::clear();
-		add_polygon(value);
+		add_polygon(value.get_list_of(Vector()));
 		sync();
 		return true;
 	}
