@@ -6,6 +6,7 @@
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**  Copyright (c) 2011 Carlos López
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -42,23 +43,16 @@ public:
 	typedef etl::handle<ValueNode_Reference> Handle;
 	typedef etl::handle<const ValueNode_Reference> ConstHandle;
 
-	ValueNode_Reference(const ValueBase::Type &x);
+	ValueNode_Reference(Type &x);
 
 	ValueNode_Reference(const ValueNode::Handle &x);
 
-//	static Handle create(const ValueBase::Type &x);
+//	static Handle create(Type &x);
 //	static Handle create(const ValueNode::Handle &x);
 
 
 	virtual ValueNode::LooseHandle get_link_vfunc(int i)const;
 
-	virtual int link_count()const;
-
-	virtual String link_name(int i)const;
-
-	virtual String link_local_name(int i)const;
-	virtual int get_link_index_from_name(const String &name)const;
-
 	virtual ValueBase operator()(Time t)const;
 
 	virtual ~ValueNode_Reference();
@@ -74,8 +68,9 @@ protected:
 
 public:
 	using synfig::LinkableValueNode::set_link_vfunc;
-	static bool check_type(ValueBase::Type type);
+	static bool check_type(Type &type);
 	static ValueNode_Reference* create(const ValueBase &x);
+	virtual Vocab get_children_vocab_vfunc()const;
 }; // END of class ValueNode_Reference
 
 }; // END of namespace synfig
