@@ -53,7 +53,7 @@ private:
 
 public:
 
-//	static Handle create(ValueBase::Type id);
+//	static Handle create(Type &type);
 
 	virtual ~ValueNode_TimedSwap();
 
@@ -64,7 +64,7 @@ public:
 
 	virtual String get_name()const;
 	virtual String get_local_name()const;
-//	static bool check_type(const ValueBase::Type &type);
+//	static bool check_type(Type &type);
 
 protected:
 
@@ -73,7 +73,7 @@ protected:
 public:
 	using synfig::LinkableValueNode::get_link_vfunc;
 	using synfig::LinkableValueNode::set_link_vfunc;
-	static bool check_type(ValueBase::Type type);
+	static bool check_type(Type &type);
 	static ValueNode_TimedSwap* create(const ValueBase &x);
 	virtual Vocab get_children_vocab_vfunc()const;
 }; // END of class ValueNode_TimedSwap
